summaryrefslogtreecommitdiffstats
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rwxr-xr-xbin/chroot-installation.sh10
-rwxr-xr-xbin/g-i-installation.sh5
2 files changed, 8 insertions, 7 deletions
diff --git a/bin/chroot-installation.sh b/bin/chroot-installation.sh
index 3b56cae4..1a7242cb 100755
--- a/bin/chroot-installation.sh
+++ b/bin/chroot-installation.sh
@@ -117,16 +117,16 @@ trap cleanup_all INT TERM EXIT
case $1 in
squeeze) DISTRO="squeeze"
- SPECIFIC="openoffice.org virtualbox-ose mplayer"
+ SPECIFIC="openoffice.org virtualbox-ose mplayer chromium"
;;
wheezy) DISTRO="wheezy"
- SPECIFIC="libreoffice virtualbox mplayer"
+ SPECIFIC="libreoffice virtualbox mplayer chromium"
;;
jessie) DISTRO="jessie"
- SPECIFIC="libreoffice virt-manager mplayer2"
+ SPECIFIC="libreoffice virt-manager mplayer2 chromium-browser"
;;
sid) DISTRO="sid"
- SPECIFIC="libreoffice virt-manager mplayer2"
+ SPECIFIC="libreoffice virt-manager mplayer2 chromium-browser"
;;
*) echo "unsupported distro."
exit 1
@@ -135,7 +135,7 @@ esac
bootstrap $DISTRO
if [ "$2" != "" ] ; then
- FULL_DESKTOP="$SPECIFIC desktop-base gnome kde-plasma-desktop kde-full kde-standard xfce4 lxde vlc evince iceweasel chromium cups build-essential devscripts wine texlive-full asciidoc vim emacs"
+ FULL_DESKTOP="$SPECIFIC desktop-base gnome kde-plasma-desktop kde-full kde-standard xfce4 lxde vlc evince iceweasel cups build-essential devscripts wine texlive-full asciidoc vim emacs"
case $2 in
none) ;;
gnome) install_packages gnome gnome desktop-base
diff --git a/bin/g-i-installation.sh b/bin/g-i-installation.sh
index 59d20f77..6d73a389 100755
--- a/bin/g-i-installation.sh
+++ b/bin/g-i-installation.sh
@@ -865,7 +865,7 @@ monitor_system() {
rm snapshot_${PRINTF_NR}.jpg
else
echo "$PRINTF_NR: $(date) - could not take vncsnapshot from $DISPLAY - using a blank fake one instead"
- convert -size $VIDEOSIZE xc:none snapshot_${PRINTF_NR}.ppm
+ convert -size $VIDEOSIZE xc:none -depth 8 snapshot_${PRINTF_NR}.ppm
fi
# give signal we are still running
if [ $(($NR % 14)) -eq 0 ] ; then
@@ -1077,7 +1077,8 @@ if [ ! -z "$IMAGE" ] ; then
fetch_if_newer "$IMAGE" "$URL"
# is this really an .iso?
if [ $(file "$IMAGE" | grep -cE '(ISO 9660|DOS/MBR boot sector)') -eq 1 ] ; then
- # yes, so let's mount it
+ # yes, so let's md5sum and mount it
+ md5sum $IMAGE
sudo mkdir -p $IMAGE_MNT
grep -q $IMAGE_MNT /proc/mounts && sudo umount -l $IMAGE_MNT
sleep 1